uniform sampler2D colorMap;
uniform sampler2D normalMap;

uniform bool lighting;
uniform bool absorption;
uniform vec3 planePoint;
uniform vec4 planeColor;
uniform vec3 planeNormal;

uniform bool bumpMapping;
attribute vec3 tangent;

uniform bool colorMapping;

varying float a;
varying vec2 uv;
varying vec3 lightVec;
varying vec3 eyeVec;

void main(void)
{
	if(bumpMapping) {
		vec4	base;

		if(colorMapping) {
			base=texture2D(colorMap, uv);
		}
		else {
			base=vec4(1.0, 1.0, 1.0, 1.0);
		}

		float distSqr = dot(lightVec, lightVec);
		vec3 lVec = lightVec * inversesqrt(distSqr);
		vec3 vVec = normalize(eyeVec);
		vec3 bump = normalize(texture2D(normalMap, uv).xyz * 2.0 - 1.0);

		vec4 vAmbient = gl_LightSource[0].ambient * gl_FrontMaterial.ambient;
		float diffuse = max(dot(lVec, bump), 0.0 );
		vec4 vDiffuse = gl_LightSource[0].diffuse * gl_FrontMaterial.diffuse * diffuse;

		float specular = pow(clamp(dot(reflect(-lVec, bump), vVec), 0.0, 1.0), gl_FrontMaterial.shininess);
		vec4 vSpecular = gl_LightSource[0].specular * gl_FrontMaterial.specular * specular;

		gl_FragColor = gl_FrontLightModelProduct.sceneColor + vAmbient*base  + vDiffuse*base + vSpecular;
		
	}
	else {
		if(colorMapping) {
			gl_FragColor=gl_Color*texture2D(colorMap, uv);

		}
		else {
			gl_FragColor=gl_Color;
		}
	}

	gl_FragColor = mix(gl_FragColor, planeColor, a);
}